/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef CFDSTATE_H
#define CFDSTATE_H

#include <Driver.h>
#include "CfdDriver.h"

namespace cfd {

/*!
 * \class CfdState
 * \brief Virtual class for implement State pattern
 *
 * Define all methods that perfect, simulated and real classes have to implement
 */
class CfdState: public DriverState<CfdDriver> {

public:

	/*!
	 * \brief Constructor
	 * \param[in] owner The device driver main class link
	 */
	CfdState(CfdDriver* owner) :
			DriverState<CfdDriver>(owner) {
	}

	/*!
	 * \brief Destructor
	 */
	virtual ~CfdState() {
	}

	/*!
	 * \brief Write Param command implementation
	 */
	virtual void writeParam() = 0;

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readInfos() = 0;

};

}
#endif //CFDSTATE_H
